@@ -1,4 +1,4 @@
-class Flags:
+class Flags(object):
     def __init__(self, flags=None):
         self.flags = frozenset(flags or {})
 
